@@ -41,10 +41,11 @@ class BinaryDistributionsCompiler(object):
 
     def add_import_setuptools_to_setup_py(self):
         with open("setup.py") as fd:
-            content = fd.readlines()
-        content.insert(1, "import setuptools")
+            content = fd.read()
+        content = content.replace("from distutils.core import setup", "from setuptools import setup")
+        content = content.replace("from distutils import core", "import setuptools as core")
         with open("setup.py", 'w') as fd:
-            fd.write('\n'.join(content))
+            fd.write(content)
 
     @contextmanager
     def extract_archive(self, archive_path):
@@ -90,7 +91,7 @@ class BinaryDistributionsCompiler(object):
         from os import remove
         from shutil import copy
         for archive in self.get_packages_to_install():
-            logger.debug("Compiling egg for {}".format(archive))
+            logger.info("Compiling egg for {}".format(archive))
             with self.extract_archive(archive) as extracted_dir:
                 try:
                     built_egg = self.build_binary_egg()
